@@ -124,8 +124,14 @@ TEMPLATE_README = """Auto generated readme file for %(project_name)s.
 
 Put something informative here"""
 
-TEMPLATE_SETUP = """from os.path import exists
-from distutils.core import setup
+TEMPLATE_SETUP = """#!/usr/bin/env python
+
+from os.path import exists
+try:
+    from setuptools import setup
+except ImportError:
+    from distutils.core import setup
+
 from %(package_name)s import __version__
 
 setup(
